# -*- coding: utf-8 -*-
'''Dummy driver.

Implements basic driver interface.
This is useful for debugging or when writing new driver.

@author: Radek Brich <radek.brich@devl.cz>

'''

import logging

from tuikit.common import Size, ClipStack


class DriverDummy:
    
    '''Dummy driver class'''
    
    def __init__(self):
        '''Initialize instance attributes'''
        self.log = logging.getLogger('tuikit')
        self.size = Size()
        self.clipstack = ClipStack()
    
    def start(self, mainfunc):
        '''Start driver and run mainfunc.'''
        self.size.w, self.size.h = 80, 25
        mainfunc()


    # colors
    
    def setcolor(self, name, desc):
        '''Define color name.
        
        name - name of color (e.g. 'normal', 'active')
        desc - color description - foreground, background, attributes (e.g. 'black on white, bold')
        
        '''
        self.log.info('DummyDriver.setcolor(name=%r, desc=%r)', name, desc)

    def pushcolor(self, name):
        self.log.info('DummyDriver.pushcolor(name=%r)', name)
    
    def popcolor(self):
        self.log.info('DummyDriver.popcolor()')


    # drawing
    
    def erase(self):
        '''Clear screen.'''
        self.log.info('DummyDriver.erase()')

    def puts(self, x, y, s):
        '''Output string to specified coordinates.'''
        self.log.info('DummyDriver.puts(x=%r, y=%r, s=%r)', x, y, s)

    def commit(self):
        '''Commit changes to the screen.'''
        self.log.info('DummyDriver.commit()')


    # input
    
    def process_input(self, timeout=None):
        '''Process input, return list of events.
        
        This dummy implementation just returns 'q' and Escape key presses.
        
        '''
        events = [('keypress', None, 'q'), ('keypress', 'escape', None)]
        return events

